@@ -470,36 +470,6 @@ package Sidef::Types::Array::Array {
         $self->eq($array)->neg;
     }
 
-    sub zip {
-        my ($self, @arrays) = @_;
-
-        my @new_array;
-        foreach my $i (0 .. $#$self) {
-
-            my @tmp_array = ($self->[$i]);
-            foreach my $array (@arrays) {
-                CORE::push(@tmp_array, $array->[$i]);
-            }
-
-            CORE::push(@new_array, bless(\@tmp_array, __PACKAGE__));
-        }
-
-        bless(\@new_array, __PACKAGE__);
-    }
-
-    sub mzip {
-        my ($self, $array) = @_;
-
-        my $arr_max = @$array;
-
-        my @new_array;
-        foreach my $i (0 .. $#$self) {
-            CORE::push(@new_array, $self->[$i], $array->[$i % $arr_max]);
-        }
-
-        bless(\@new_array, __PACKAGE__);
-    }
-
     sub make {
         my ($self, $size, $type) = @_;
         bless([($type) x $size], __PACKAGE__);
@@ -608,12 +578,12 @@ package Sidef::Types::Array::Array {
     }
 
     sub max_by {
-        push @_, 1;
+        @_ = (@_[0, 1], 1);
         goto \&_min_max_by;
     }
 
     sub min_by {
-        push @_, -1;
+        @_ = (@_[0, 1], -1);
         goto \&_min_max_by;
     }
 
@@ -964,13 +934,10 @@ package Sidef::Types::Array::Array {
 
         my %hash;
         foreach my $item (@$self) {
-            my $key = $code->run(my $val = $item);
-            my $str_key = "$key";
-            exists($hash{$str_key}) or do { $hash{$str_key} = bless([], __PACKAGE__) };
-            CORE::push(@{$hash{$str_key}}, $val);
+            CORE::push(@{$hash{$code->run($item)}}, $item);
         }
 
-        Sidef::Types::Hash::Hash->new(%hash);
+        Sidef::Types::Hash::Hash->new(map { $_ => bless($hash{$_}, __PACKAGE__) } CORE::keys(%hash));
     }
 
     sub match {
@@ -1021,14 +988,22 @@ package Sidef::Types::Array::Array {
 
         my %hash;
         foreach my $item (@$self) {
-            $hash{$code->run($item)}++;
+            my $r = $hash{$code->run($item)} //= {
+                                                  count => 0,
+                                                  items => [],
+                                                 };
+            CORE::push(@{$r->{items}}, $item);
+            ++$r->{count};
         }
 
-        foreach my $key (keys %hash) {
-            $hash{$key} = Sidef::Types::Number::Number->_set_uint($hash{$key});
+        my %freq;
+        foreach my $key (CORE::keys(%hash)) {
+            my $r = $hash{$key};
+            my $n = Sidef::Types::Number::Number->_set_uint($r->{count});
+            @freq{@{$r->{items}}} = ($n) x scalar(@{$r->{items}});
         }
 
-        Sidef::Types::Hash::Hash->new(%hash);
+        Sidef::Types::Hash::Hash->new(%freq);
     }
 
     sub freq {
@@ -1043,7 +1018,7 @@ package Sidef::Types::Array::Array {
             $hash{$item}++;
         }
 
-        foreach my $key (keys %hash) {
+        foreach my $key (CORE::keys %hash) {
             $hash{$key} = Sidef::Types::Number::Number->_set_uint($hash{$key});
         }
 
@@ -1869,6 +1844,87 @@ package Sidef::Types::Array::Array {
     *permutation = \&permutations;    # deprecated
     *each_perm   = \&permutations;
 
+    sub cartesian {
+        my ($self, $block) = @_;
+
+        my (@c, @r);
+        my @C = @$self;
+
+        my $p;
+        $p = sub {
+            if (@c < @C) {
+                for my $item (@{$C[@c]}) {
+                    CORE::push(@c, $item);
+                    __SUB__->();
+                    CORE::pop(@c);
+                }
+            }
+            else {
+                if (defined($block)) {
+                    $block->run(bless [@c], __PACKAGE__);
+                }
+                else {
+                    CORE::push @r, bless [@c], __PACKAGE__;
+                }
+            }
+        };
+
+        $p->();
+        $p = undef;
+
+        defined($block)
+          ? $self
+          : bless(\@r, __PACKAGE__);
+    }
+
+    sub zip {
+        my ($self, $block) = @_;
+
+        my @arrays = @{$self};
+        my $min = List::Util::min(map { scalar @$_ } @arrays);
+
+        my @first = @{CORE::shift(@arrays)};
+
+        my @new_array;
+        foreach my $i (0 .. $min - 1) {
+
+            my @tmp = ($first[$i], map { $_->[$i] } @arrays);
+
+            if (defined($block)) {
+                $block->run(bless(\@tmp, __PACKAGE__));
+            }
+            else {
+                CORE::push(@new_array, bless(\@tmp, __PACKAGE__));
+            }
+        }
+
+        defined($block) ? $self : bless(\@new_array, __PACKAGE__);
+    }
+
+    sub mzip {
+        my ($self, $block) = @_;
+
+        my @arrays = @{$self};
+        my $min = List::Util::min(map { scalar @$_ } @arrays);
+
+        my @first = @{CORE::shift(@arrays)};
+
+        my @new_array;
+        foreach my $i (0 .. $#first) {
+
+            my @tmp = ($first[$i], map { $_->[$i % $min] } @arrays);
+
+            if (defined($block)) {
+                $block->run(bless(\@tmp, __PACKAGE__));
+            }
+            else {
+                CORE::push(@new_array, bless(\@tmp, __PACKAGE__));
+            }
+        }
+
+        defined($block) ? $self : bless(\@new_array, __PACKAGE__);
+    }
+
     sub pack {
         my ($self, $format) = @_;
         Sidef::Types::String::String->new(CORE::pack("$format", @$self));
@@ -1950,7 +2006,7 @@ package Sidef::Types::Array::Array {
 
     sub copy {
         my ($self) = @_;
-        state $x = warn "[WARN] Array.copy() is deprecated: use .clone() or .dclone() instead!\n";
+        state $x = warn "[WARNING] Array.copy() is deprecated: use .clone() or .dclone() instead!\n";
         $self->dclone;
     }
 
