@@ -150,6 +150,12 @@ package Sidef::Types::Hash::Hash {
 
     *remove = \&delete;
 
+    sub set_keys {
+        my ($self, @keys) = @_;
+        undef @{$self}{@keys};
+        $self;
+    }
+
     sub map_val {
         my ($self, $code) = @_;
 
@@ -479,7 +485,7 @@ package Sidef::Types::Hash::Hash {
 
     sub copy {
         my ($self) = @_;
-        state $x = warn "[WARN] Hash.copy() is deprecated: use .clone() or .dclone() instead!\n";
+        state $x = warn "[WARNING] Hash.copy() is deprecated: use .clone() or .dclone() instead!\n";
         $self->dclone;
     }
 
