@@ -67,6 +67,7 @@ package Sidef::Types::Number::Inf {
     *is_nan            = \&is_real;
     *is_neg            = \&is_real;
     *is_prime          = \&is_real;
+    *is_semiprime      = \&is_real;
     *is_prob_prime     = \&is_real;
     *is_prov_prime     = \&is_real;
     *is_mersenne_prime = \&is_real;
@@ -88,66 +89,72 @@ package Sidef::Types::Number::Inf {
 
     sub nan { Sidef::Types::Number::Nan::NAN }
 
-    *mod               = \&nan;
-    *imod              = \&nan;
-    *fmod              = \&nan;
-    *frem              = \&nan;
-    *bin               = \&nan;
-    *modpow            = \&nan;
-    *expmod            = \&nan;
-    *powmod            = \&nan;
-    *modinv            = \&nan;
-    *invmod            = \&nan;
-    *and               = \&nan;
-    *or                = \&nan;
-    *xor               = \&nan;
-    *legendre          = \&nan;
-    *jacobi            = \&nan;
-    *kronecker         = \&nan;
-    *gcd               = \&nan;
-    *lcm               = \&nan;
-    *next_power2       = \&nan;
-    *next_pow2         = \&nan;
-    *next_pow          = \&nan;
-    *next_power        = \&nan;
-    *next_prime        = \&nan;
-    *prev_prime        = \&nan;
-    *digit             = \&nan;
-    *bernreal          = \&nan;
-    *bernfrac          = \&nan;
-    *bern              = \&nan;
-    *bernoulli         = \&nan;
-    *valuation         = \&nan;
-    *popcount          = \&nan;
-    *mobius            = \&nan;
-    *moebius           = \&nan;
-    *sigma             = \&nan;
-    *sigma0            = \&nan;
-    *omega             = \&nan;
-    *big_omega         = \&nan;
-    *prime_root        = \&nan;
-    *prime_power       = \&nan;
-    *perfect_root      = \&nan;
-    *perfect_power     = \&nan;
-    *totient           = \&nan;
-    *euler_phi         = \&nan;
-    *euler_totient     = \&nan;
-    *jordan_totient    = \&nan;
-    *carmichael_lambda = \&nan;
-    *liouville         = \&nan;
-    *exp_mangoldt      = \&nan;
-    *stirling          = \&nan;
-    *stirling2         = \&nan;
-    *stirling3         = \&nan;
-    *znorder           = \&nan;
-    *znprimroot        = \&nan;
-    *ramanujan_tau     = \&nan;
-    *prime_count       = \&nan;
-    *remove            = \&nan;
-    *rad               = \&nan;
-    *bessel_j          = \&nan;
-    *bessel_y          = \&nan;
-    *beta              = \&nan;
+    *mod                 = \&nan;
+    *imod                = \&nan;
+    *fmod                = \&nan;
+    *frem                = \&nan;
+    *bin                 = \&nan;
+    *modpow              = \&nan;
+    *expmod              = \&nan;
+    *powmod              = \&nan;
+    *modinv              = \&nan;
+    *invmod              = \&nan;
+    *and                 = \&nan;
+    *or                  = \&nan;
+    *xor                 = \&nan;
+    *legendre            = \&nan;
+    *jacobi              = \&nan;
+    *kronecker           = \&nan;
+    *gcd                 = \&nan;
+    *lcm                 = \&nan;
+    *next_power2         = \&nan;
+    *next_pow2           = \&nan;
+    *next_pow            = \&nan;
+    *next_power          = \&nan;
+    *next_prime          = \&nan;
+    *prev_prime          = \&nan;
+    *digit               = \&nan;
+    *bernreal            = \&nan;
+    *bernfrac            = \&nan;
+    *bern                = \&nan;
+    *bernoulli           = \&nan;
+    *valuation           = \&nan;
+    *popcount            = \&nan;
+    *mobius              = \&nan;
+    *moebius             = \&nan;
+    *sigma               = \&nan;
+    *sigma0              = \&nan;
+    *omega               = \&nan;
+    *big_omega           = \&nan;
+    *prime_root          = \&nan;
+    *prime_power         = \&nan;
+    *perfect_root        = \&nan;
+    *perfect_power       = \&nan;
+    *totient             = \&nan;
+    *euler_phi           = \&nan;
+    *euler_totient       = \&nan;
+    *jordan_totient      = \&nan;
+    *carmichael_lambda   = \&nan;
+    *liouville           = \&nan;
+    *exp_mangoldt        = \&nan;
+    *stirling            = \&nan;
+    *stirling2           = \&nan;
+    *stirling3           = \&nan;
+    *znorder             = \&nan;
+    *znprimroot          = \&nan;
+    *ramanujan_tau       = \&nan;
+    *prime_count         = \&nan;
+    *square_free_count   = \&nan;
+    *remove              = \&nan;
+    *rad                 = \&nan;
+    *bessel_j            = \&nan;
+    *bessel_y            = \&nan;
+    *beta                = \&nan;
+    *prime               = \&nan;
+    *nth_prime           = \&nan;
+    *random_prime        = \&nan;
+    *random_nbit_prime   = \&nan;
+    *random_ndigit_prime = \&nan;
 
     *harm     = \&inf;
     *harmonic = \&inf;
@@ -165,12 +172,12 @@ package Sidef::Types::Number::Inf {
         Sidef::Types::Array::Array->new([]);
     }
 
-    *factor   = \&digits;
-    *factors  = \&digits;
-    *pfactor  = \&digits;
-    *pfactors = \&digits;
-    *primes   = \&digits;
-    *divisors = \&digits;
+    *factor      = \&digits;
+    *factors     = \&digits;
+    *factor_exp  = \&digits;
+    *factors_exp = \&digits;
+    *primes      = \&digits;
+    *divisors    = \&digits;
 
     sub divmod {
         my ($x, $y) = @_;
@@ -247,6 +254,7 @@ package Sidef::Types::Number::Inf {
     *inc              = \&inf;
     *dec              = \&inf;
     *int              = \&inf;
+    *trunc            = \&inf;
     *as_int           = \&inf;
     *float            = \&inf;
     *as_float         = \&inf;
